netapp_ontap.models.application_protection_groups_rpo_remote API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_protection_groups_rpo_remote`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationProtectionGroupsRpoRemoteSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationProtectionGroupsRpoRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `description GET`

    A detailed description of the remote RPO.

  `name GET`

    The remote RPO of the component. A remote RPO of zero indicates that the component is synchronously replicated to another cluster.

    Valid choices:

    - none
    - zero
    - hourly
    - 6_hourly
    - 15_minutely